==> haskell-terminal-progress-bar-0.4.2-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-terminal-progress-bar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 terminal-progress-bar
version:              0.4.2
visibility:           public
id:                   terminal-progress-bar-0.4.2-3T7sJOW3w895IF1BabhyBf
key:                  terminal-progress-bar-0.4.2-3T7sJOW3w895IF1BabhyBf
license:              BSD-3-Clause
copyright:            2012–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
homepage:             https://github.com/roelvandijk/terminal-progress-bar
synopsis:             A progress bar in the terminal
description:
    A progress bar conveys the progress of a task. This package
    implements a progress bar that is displayed in a terminal.

    See the module '\''System.ProgressBar'\'' to get started or look at the
    terminal-progress-bar-example package.

    The animated progress bar depends entirely on the interpretation of
    the carriage return character (\'\''\\r\'\''). If your terminal interprets
    it as something else than \"move cursor to beginning of line\", the
    animation won'\''t work.

category:             System, User Interfaces
abi:                  7a0bcccc6610fb2a8e1457218e57cca4
exposed:              True
exposed-modules:      System.ProgressBar
import-dirs:          /usr/lib/ghc-9.2.8/site-local/terminal-progress-bar-0.4.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/terminal-progress-bar-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-terminal-progress-bar
hs-libraries:         HSterminal-progress-bar-0.4.2-3T7sJOW3w895IF1BabhyBf
depends:
    base-4.16.4.0 deepseq-1.4.6.1
    terminal-size-0.3.4-7GJNKkuDjwr8c9rYP2Bu9E text-1.2.5.0
    time-1.11.1.1

haddock-interfaces:
    /usr/share/doc/haskell-terminal-progress-bar/html/terminal-progress-bar.haddock

haddock-html:         /usr/share/doc/haskell-terminal-progress-bar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-terminal-progress-bar-0.4.2-52.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-terminal-progress-bar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 terminal-progress-bar
version:              0.4.2
visibility:           public
id:                   terminal-progress-bar-0.4.2-7zaKNqrkA1ZAebKLbqT81S
key:                  terminal-progress-bar-0.4.2-7zaKNqrkA1ZAebKLbqT81S
license:              BSD-3-Clause
copyright:            2012–2019 Roel van Dijk <roel@lambdacube.nl>
maintainer:           Roel van Dijk <roel@lambdacube.nl>
author:               Roel van Dijk <roel@lambdacube.nl>
homepage:             https://github.com/roelvandijk/terminal-progress-bar
synopsis:             A progress bar in the terminal
description:
    A progress bar conveys the progress of a task. This package
    implements a progress bar that is displayed in a terminal.

    See the module '\''System.ProgressBar'\'' to get started or look at the
    terminal-progress-bar-example package.

    The animated progress bar depends entirely on the interpretation of
    the carriage return character (\'\''\\r\'\''). If your terminal interprets
    it as something else than \"move cursor to beginning of line\", the
    animation won'\''t work.

category:             System, User Interfaces
abi:                  5ea4318b183f50973e4775c2027636d0
exposed:              True
exposed-modules:      System.ProgressBar
import-dirs:          /usr/lib/ghc-9.4.8/site-local/terminal-progress-bar-0.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/terminal-progress-bar-0.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/terminal-progress-bar-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-terminal-progress-bar
hs-libraries:         HSterminal-progress-bar-0.4.2-7zaKNqrkA1ZAebKLbqT81S
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    terminal-size-0.3.4-G9QKE0nIH70HWdqrMvHn0A text-2.0.2 time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-terminal-progress-bar/html/terminal-progress-bar.haddock

haddock-html:         /usr/share/doc/haskell-terminal-progress-bar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
